# - Find an IGSTK Sandbox installation or build tree.

# When IGSTK Sandbox is found, the IGSTKSandboxConfig.cmake file is sourced to setup the
# location and configuration of IGSTK Sandbox.  Please read this file, or
# IGSTKSandboxConfig.cmake.in from the IGSTK Sandbox source tree for the full list of
# definitions.  Of particular interest is IGSTKSandbox_USE_FILE, a CMake source file
# that can be included to set the include directories, library directories,
# and preprocessor macros.  In addition to the variables read from
# IGSTKSandboxConfig.cmake, this find module also defines
#  IGSTKSandbox_DIR  - The directory containing IGSTKSandboxConfig.cmake.  
#             This is either the root of the build tree
#   
#  IGSTKSandbox_FOUND - Whether IGSTK Sandbox was found.  If this is true, 
#              IGSTKSandbox_DIR is okay.
#
#  USE_IGSTKSandbox_FILE - The full path to the UseIGSTK.cmake file.  
#                 This is provided for backward 
#                 compatability.  Use IGSTKSandbox_USE_FILE
#                 instead.

FIND_PATH(IGSTKSandbox_DIR IGSTKSandboxConfig.cmake /usr/local/igstk/Sandbox DOC "Igstk Sandbox directory")

# path is okay
IF (EXISTS ${IGSTKSandbox_DIR}/IGSTKSandboxConfig.cmake)

  SET(IGSTKSandbox_FOUND 1)
  INCLUDE (${IGSTKSandbox_DIR}/IGSTKSandboxConfig.cmake)

  IF ( EXISTS ${IGSTKSandbox_FLTK_DIR})
    SET ( FLTK_DIR ${IGSTKSandbox_FLTK_DIR})
    FIND_PACKAGE(FLTK)
  
    IF (FLTK_FOUND)
    
      INCLUDE_DIRECTORIES (${FLTK_INCLUDE_DIR})
      IF(WIN32)
        ADD_DEFINITIONS(-DWIN32)
      ENDIF(WIN32)
      LINK_LIBRARIES( ${FLTK_LIBRARIES} ${OPENGL_LIBRARIES} )
      IF(CYGWIN)
        LINK_LIBRARIES( ole32 uuid comctl32 wsock32 supc++ -lm -lgdi32)
      ENDIF(CYGWIN)
    ENDIF (FLTK_FOUND)

  ENDIF ( EXISTS ${IGSTKSandbox_FLTK_DIR})

ELSE (EXISTS ${IGSTKSandbox_DIR}/IGSTKSandboxConfig.cmake)

  SET(IGSTKSandbox_FOUND 0)
  IF(IGSTKSandbox_FIND_REQUIRED)
    MESSAGE(FATAL_ERROR "Please set IGSTKSandbox_DIR to the correct value")
  ENDIF(IGSTKSandbox_FIND_REQUIRED)
ENDIF(IGSTKSandbox_DIR)

ENDIF (EXISTS ${IGSTKSandbox_DIR}/IGSTKSandboxConfig.cmake)
