/*=========================================================================

  Program:   Image Guided Surgery Software Toolkit
  Module:    $RCSfile: OneViewAndTrackingUsingQTWidgetGUI.cxx,v $
  Language:  C++
  Date:      $Date: 2008/01/09 21:25:20 $
  Version:   $Revision: 1.16 $

  Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
  See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#include <QtGui>
#include "OneViewAndTrackingUsingQTWidgetGUI.moc"
#include "OneViewAndTrackingUsingQTWidgetGUI.h"

OneViewAndTrackingUsingQTWidgetGUI::OneViewAndTrackingUsingQTWidgetGUI()
{
  ui.setupUi(this);
  this->CreateActions();

  m_Logger = LoggerType::New();
  m_LogOutput = LogOutputType::New();
  m_LogFile.open("logOneViewAndTrackingUsingFLTKWidget.txt");
  if( !m_LogFile.fail() )
    {
    m_LogOutput->SetStream( m_LogFile );
    }
  else
    {
    std::cerr << "Problem opening Log file, using cerr instead " 
      << std::endl;
    m_LogOutput->SetStream( std::cerr );
    }
  m_Logger->AddLogOutput( m_LogOutput );

  // add stdout for debug purposes
  LogOutputType::Pointer coutLogOutput = LogOutputType::New();
  coutLogOutput->SetStream( std::cout );
  m_Logger->AddLogOutput( coutLogOutput );

  m_Logger->SetPriorityLevel( LoggerType::DEBUG );

  m_GUIQuit  = false;

  ui.Display3D->SetLogger( m_Logger );

  ui.RemoveButton->setEnabled(false);
  
  m_Cylinder = igstk::CylinderObject::New();
  m_Cylinder->SetRadius(1.0);
  m_Cylinder->SetHeight(300.0);  // about the size of a needle
  
  //Set up an observer for the transform modified event
  m_ViewPickerObserver = ObserverType::New();
  m_ViewPickerObserver->SetCallbackFunction( this, 
                                               &OneViewAndTrackingUsingQTWidgetGUI::ParsePickedPoint );
}

OneViewAndTrackingUsingQTWidgetGUI::~OneViewAndTrackingUsingQTWidgetGUI()
{
}

void OneViewAndTrackingUsingQTWidgetGUI::CreateActions()
{
  connect(ui.QuitPushButton, SIGNAL(clicked()), this, SLOT(OnQuitAction()));
  connect(ui.AddButton, SIGNAL(clicked() ), this,
          SLOT(OnAddingAction()));
  connect(ui.RemoveButton, SIGNAL(clicked() ), this,
          SLOT(OnRemovingAction()));
}

void OneViewAndTrackingUsingQTWidgetGUI::OnQuitAction()
{
  QMessageBox::StandardButton value = 
    QMessageBox::information(this,
    "Tracking application", "Are you sure you want to quit ?",
    QMessageBox::Yes | QMessageBox::No );

  if( value == QMessageBox::Yes )
    {
    this->close();
    m_GUIQuit = true;
    }
}

void OneViewAndTrackingUsingQTWidgetGUI::SetView( igstk::View * view )
{
  m_View = view;
  ui.Display3D->RequestSetView (view);
  ui.Display3D->AddObserver( igstk::TransformModifiedEvent(), 
			     m_ViewPickerObserver );

  double aLongTime = 1e300; // in seconds
  igstk::Transform transform;
  igstk::Transform::VectorType translation;
  translation[0] = 0.0;
  translation[1] = 0.0;
  translation[2] = 0.0;
  igstk::Transform::VersorType rotation;
  rotation.Set( 0.0, 0.0, 0.0, 1.0 );
  igstk::Transform::ErrorType errorValue = 10; // 10 millimeters

  transform.SetTranslationAndRotation( 
				      translation, rotation, errorValue, aLongTime );

  // cylinder coordinates are relative to the ellipse
  m_Cylinder->RequestSetTransformAndParent( transform, m_View.GetPointer() );

}

void OneViewAndTrackingUsingQTWidgetGUI::OnRemovingAction( )
{
  if( m_View.IsNotNull())
    {
      //remove last representation
      igstk::CylinderObjectRepresentation::Pointer igstkRep = m_Representations.at(m_Representations.size()-1);
      m_View->RequestRemoveObject( igstkRep );
      m_Representations.pop_back();
      if ( m_Representations.size() == 0)
	ui.RemoveButton->setEnabled(false);
    }

}

void OneViewAndTrackingUsingQTWidgetGUI::OnAddingAction( )
{
  if( m_View.IsNotNull())
    {
      igstk::CylinderObjectRepresentation::Pointer  m_CylinderRepresentation = igstk::CylinderObjectRepresentation::New();
      m_CylinderRepresentation->RequestSetCylinderObject( m_Cylinder );
      m_CylinderRepresentation->SetColor(0.0,0.0,1.0);
      m_CylinderRepresentation->SetOpacity(1.0);
      
      m_View->RequestAddObject( m_CylinderRepresentation);
      m_Representations.push_back(m_CylinderRepresentation);
      ui.RemoveButton->setEnabled( true );
    }
}

bool OneViewAndTrackingUsingQTWidgetGUI::HasQuitted( ) 
{
  return m_GUIQuit;
}

void OneViewAndTrackingUsingQTWidgetGUI::ParsePickedPoint( const itk::EventObject & event)
{
  if ( igstk::TransformModifiedEvent().CheckEvent( &event ) )
    {
    igstk::TransformModifiedEvent *tmevent = 
                                     ( igstk::TransformModifiedEvent *) & event;
    
    std::cout << "Translation transform: " << tmevent->Get().GetTranslation()[0] << "\t"
                                           << tmevent->Get().GetTranslation()[1] << "\t"
                                           << tmevent->Get().GetTranslation()[2]
                                           << std::endl;
    }
}


