/*=========================================================================

  Program:   Image Guided Surgery Software Toolkit
  Module:    $RCSfile: OneViewAndTrackingUsingQTWidgetGUI.h,v $
  Language:  C++
  Date:      $Date: 2008/01/09 21:25:20 $
  Version:   $Revision: 1.17 $

  Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
  See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#
#ifndef __OneViewAndTrackingUsingQTWidgetGUI_h
#define __OneViewAndTrackingUsingQTWidgetGUI_h

#include <QtGui>

#include "igstkCylinderObject.h"
#include "igstkCylinderObjectRepresentation.h"
#include "igstkView.h"
#include "igstkLogger.h"
#include "itkStdStreamLogOutput.h"

#include "ui_OneViewAndTrackingUsingQTWidgetGUI.h"

class OneViewAndTrackingUsingQTWidgetGUI : public QMainWindow
{
  Q_OBJECT

  typedef igstk::Object::LoggerType    LoggerType; 
  typedef itk::StdStreamLogOutput      LogOutputType;

public:
  OneViewAndTrackingUsingQTWidgetGUI();
  ~OneViewAndTrackingUsingQTWidgetGUI();
  void SetView( igstk::View * view );
  bool HasQuitted();

public slots:
  void OnQuitAction();
  void OnAddingAction();
  void OnRemovingAction();

private:
  void CreateActions();

  Ui::MainWindow ui;

  LoggerType::Pointer         m_Logger;
  LogOutputType::Pointer      m_LogOutput;

  // internal cylinder for test purpose
  igstk::CylinderObject::Pointer m_Cylinder;

  // representations list for test purpose
  std::vector < igstk::CylinderObjectRepresentation::Pointer > m_Representations;

  igstk::View::Pointer        m_View;
  
  std::ofstream           m_LogFile;
  bool                    m_GUIQuit;

  typedef itk::ReceptorMemberCommand < OneViewAndTrackingUsingQTWidgetGUI > ObserverType;
  ObserverType::Pointer                       m_ViewPickerObserver;


  /** Callback functions for picking */ 
  void ParsePickedPoint( const itk::EventObject & event );

};

#endif
